/*

 *    CollectionInfoDialog.java
 *    Copyright (C) 2001 New Zealand Digital Library Project

 *

 *    This program is free software; you can redistribute it and/or modify

 *    it under the terms of the GNU General Public License as published by

 *    the Free Software Foundation; either version 2 of the License, or

 *    (at your option) any later version.

 *

 *    This program is distributed in the hope that it will be useful,

 *    but WITHOUT ANY WARRANTY; without even the implied warranty of

 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the

 *    GNU General Public License for more details.

 *

 *    You should have received a copy of the GNU General Public License

 *    along with this program; if not, write to the Free Software

 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

 */


package org.nzdl.gsdl.SimpleGraphicalClient;

import javax.swing.*;
import javax.swing.text.*;
import javax.swing.text.html.*;
import java.awt.*;
import java.awt.event.*;
import java.util.*;
import java.text.*;
import java.io.*;

import org.nzdl.gsdl.service.*;

public class CollectionInfoDialog extends JDialog implements ActionListener, Constants {

private JButton okButton;
private JPanel  buttonPanel, holderPanel, contentPanel, collectionNamePanel;
private String publicString, betaString;
private String fullCollectionName = "";
private String descString = "";
private NumberFormat numFormat = NumberFormat.getInstance();

CollectionInfoDialog(Frame f, String collectionName, NzdlService nzdl) {
    super(f, "Collection Information" );

    contentPanel = new JPanel(new GridLayout(0,2, 5, 4));;
    buttonPanel = new JPanel();

    NzdlCollectionInfo collectionInfo =  nzdl.getCollectionInfo(collectionName);
    Set n = nzdl.getMetaData(collectionName, "collection", "collectionname");
      if (n.size() == 1) {
	fullCollectionName =  (String) n.toArray()[0];
     }
    else {
    System.err.println(collectionName + " has more than 1 collectionname");
    }
    n.clear();

    collectionNamePanel = new JPanel();
    // collectionNamePanel.setBorder(BorderFactory.createEmptyBorder(2,2,2,2));
    collectionNamePanel.add(new JLabel(fullCollectionName));

    contentPanel.add(new JLabel("Short collection name:"));
    JLabel collectionLabel = new JLabel(collectionName);
    contentPanel.add(collectionLabel);
    contentPanel.add(new JLabel("Number of Documents:"));
    String numOfDocs = numFormat.format( collectionInfo.getNumOfDocs());
    contentPanel.add(new JLabel(numOfDocs));
    contentPanel.add(new JLabel("Number of Words:"));
    String numOfWords = numFormat.format( collectionInfo.getNumOfWords());
    contentPanel.add(new JLabel(numOfWords));
    contentPanel.add(new JLabel("Size:"));
    long numOfBytes = collectionInfo.getNumOfBytes();
    contentPanel.add(new JLabel(formatByteSize(numOfBytes)));
    contentPanel.add(new JLabel("Last built on:"));
    Date buildDate = new Date( collectionInfo.getBuildDate()*1000);
    contentPanel.add(new JLabel(DateFormat.getDateTimeInstance().format(buildDate)));
    contentPanel.add(new JLabel("Is it Public?"));

    if (collectionInfo.isPublic())
	publicString = "yes";
    else
	publicString = "no";
    contentPanel.add(new JLabel(publicString));
    contentPanel.add(new JLabel("Is it beta?"));
    if (collectionInfo.isBeta())
	betaString = "yes";
    else
	betaString = "no";
    contentPanel.add(new JLabel(betaString));

    JPanel descPanel = new JPanel();
    Set descSet = nzdl.getMetaData(collectionName, "collection", "collectionextra");
    if (descSet.size() == 1) {
	descString = (String) descSet.toArray()[0];
	//System.err.println(descString);
	if (descString.length() > 0) {
	    descPanel.setBorder(BorderFactory.createCompoundBorder(BorderFactory.createEmptyBorder(10,2,5,2), BorderFactory.createTitledBorder("Description")));
	    JTextPane descPane = new JTextPane();
	    HTMLEditorKit htmlEditorKit = new HTMLEditorKit();
	    HTMLDocument htmlDoc = new HTMLDocument();
	    descPane.setEditorKit(htmlEditorKit);
	    try {
		htmlEditorKit.read(new StringReader(descString), htmlDoc, 0); 
	    }
	    catch (Exception e) {
		System.err.println(e);
	    }
	    descPane.setEditable(false);
	    descPane.setFont(docFont);
	    descPane.setDocument(htmlDoc);
	    descPane.setCaretPosition(1); // we know descString.length() > 0
	    JScrollPane scrollPane = new JScrollPane(descPane);
	    scrollPane.setPreferredSize(new Dimension(420, 130));
	    descPanel.add(scrollPane);
	} // if
    } // if 
    descSet.clear();

    okButton = new JButton("Ok");
    okButton.setPreferredSize(new Dimension(80,20));
    okButton.addActionListener(this);
    buttonPanel.add( okButton );
    getRootPane().setDefaultButton(okButton);
    
    holderPanel = new JPanel();
    holderPanel.setBorder(BorderFactory.createEmptyBorder(10,10,2,10));
    holderPanel.setLayout( new BoxLayout(holderPanel, BoxLayout.Y_AXIS));
    holderPanel.add(collectionNamePanel);
    holderPanel.add(contentPanel);
    if (descString.length() > 0) {
	holderPanel.add(Box.createVerticalStrut(10));
	holderPanel.add(descPanel); // only if we have a description to show
    }
    holderPanel.add(Box.createVerticalStrut(5));
    holderPanel.add(buttonPanel);
    getContentPane().add(holderPanel);
    pack();
    setVisible(true);
    } //end CollectionInfoDialog constructor



public void actionPerformed(ActionEvent e) {
    Object source = e.getSource();
    if (source == okButton)
	{
	    //System.err.println("ok button pressed!");

	    dispose(); //close window
	}
    else
	{
		System.err.println("event not processed in CollectionInfoDialog");
	}
} //end actionPerformed


    /* generate a string with correct sizing information */
    /* bytes, K or G */
    public String formatByteSize (long numberOfBytes) {
	int minfd = numFormat.getMinimumFractionDigits();
	int maxfd = numFormat.getMaximumFractionDigits();
	String resultString;
	numFormat.setMinimumFractionDigits(1);
	numFormat.setMaximumFractionDigits(1);
	if (numberOfBytes > 1073741824)
	     resultString =  numFormat.format((numberOfBytes / (float)1073741824)) + " G";
	else 
	    if (numberOfBytes > 1048576)
		resultString = numFormat.format((numberOfBytes / (float)1048576)) + " M";
	    else {
		numFormat.setMinimumFractionDigits(0);
		numFormat.setMaximumFractionDigits(0);
		if (numberOfBytes > 1024)
		    resultString = numFormat.format((numberOfBytes / (float)1024)) + " K";
	        else
		    resultString =  numFormat.format(numberOfBytes) + " bytes";
	    }
	numFormat.setMinimumFractionDigits(minfd);
	numFormat.setMaximumFractionDigits(maxfd);
        return resultString;
} // end formatByteSize



} // end CollectionInfoDialog class
