/*
 *    TODO.java
 *    Copyright (C) 2000 Stuart Yeates 
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

// the package we're in
package org.nzdl.gsdl.classification;

// java standard library classes used
import java.util.Enumeration;
import java.util.Vector;
import java.util.Properties;

/**
 * Class ...
 *
 * Based on algorithms in ...
 *
 * @author stuart yeates (say1@cs.waikato.ac.nz)
 * @version $Revision: 2191 $
 * @see
 * @see
 * @see
 * 
 */

public class DeweyDecimalCollectionsPolicy implements CollectionsPolicy
{
  Properties byClass = null;

  DeweyDecimalCollectionsPolicy() {
    byClass = new Properties();
  }
  DeweyDecimalCollectionsPolicy(Properties p) {
    byClass = p;
  }

  /**
   * Get the ClassificationSystem used by the CollectionsPolicy
   * 
   * @return ClassificationSystem
   * @see ClassificationSystem
   */  
  public ClassificationSystem getClassificationSystem(){
    return DeweyDecimalClassificationSystem.getInstance();
  }
  /**
   * Assign a level to a piece of metadata. 
   *
   * The metadata must be in a format understood by the 
   * ClassificationSystem used by the CollectionsPolicy
   * 
   * @param metadata the metadata
   * @return the level
   * @see ClassificationSystem
   */
  public int level(String metadata){
    Enumeration e = getClassificationSystem().parse(metadata);
    if (e.hasMoreElements())
      return ((Integer)byClass.get(e.nextElement())).intValue();
    else
      return 0;
  }

  /**
   * Assign a level to a collection of metadata. 
   *
   * The metadata must be in a format understood by the 
   * ClassificationSystem used by the CollectionsPolicy
   * 
   * @exception java.io.IOException when ...
   * @param metadata the metadata
   * @return the level
   * @see ClassificationSystem
   */
  public int level(String[] metadata) {
    int top = 0;
    for (int i = 0; i < metadata.length; i++)
      top = Math.max(top, level(metadata[i]));
    return top;
  }
  
  /**
   * Get all Classifications for a given level
   * 
   * @exception java.io.IOException when ...
   * @param level the level for which Classifications are returned
   * @return the Classifications
   * @see Classification
   */
  public Enumeration getClassificationsForLevel(int level){
    Vector vec = new Vector ();
    Enumeration e = byClass.keys();
    while (e.hasMoreElements()) {
      Classification c = (Classification) e.nextElement();
      Integer I = (Integer) byClass.get(c);
      int i = I.intValue();
      if (i == level)
	vec.add(c);
    }
    return vec.elements();
  }

  /**
   * Tests...
   *
   * 
   * @param args the arguments ...
   */

  public static void main(String args[])
  {
    Properties p = new Properties();
    p.put("004",new Integer(5));
    p.put("005",new Integer(5));
    p.put("006",new Integer(5));
    p.put("001",new Integer(4));
    p.put("002",new Integer(4));
    p.put("003",new Integer(4));
    DeweyDecimalCollectionsPolicy policy = new DeweyDecimalCollectionsPolicy(p);

    System.out.println("the level of 001 should is: " + policy.level("001") + " should be 4");
    System.out.println("the level of 002 should is: " + policy.level("002") + " should be 4");
    System.out.println("the level of 003 should is: " + policy.level("003") + " should be 4");
    System.out.println("the level of 004 should is: " + policy.level("004") + " should be 5");
    System.out.println("the level of 005 should is: " + policy.level("005") + " should be 5");
    System.out.println("the level of 006 should is: " + policy.level("006") + " should be 5");
    System.out.println("the level of 010 should is: " + policy.level("010") + " should be 0");
    System.out.println("the level of 005.5 should is: " + policy.level("005.5") + " should be 5");
    
    
  }
}

